% Reading EK60 raw data file
% Simrad, Lars Nonboe Andersen, 1/8-05|

clear all
close all

[filename, pathname] = uigetfile('*.raw', 'Select raw data file','c:\');
fname = [pathname filename];

headerlength = 12; % Bytes in datagram header

pingno = 0;

fid = fopen(fname,'r');
if (fid==-1)
    error('Could not open file');
else
    % Read configuration datagram
    length = fread(fid,1,'int32');
    dgheader = readdgheader(fid);
    configheader = readconfigheader(fid);
    for i=1:configheader.transducercount,
        configtransducer(i) = readconfigtransducer(fid);
    end
    config = struct('header',configheader,'transducer',configtransducer);
    length = fread(fid,1,'int32');  
    
    % Read NMEA, Annotation, or Sample datagram
    while (1) 
        length = fread(fid,1,'int32');
        if (feof(fid))
            break
        end
        dgheader = readdgheader(fid);
        switch (dgheader.datagramtype)
        case 'NME0' % NMEA datagram
            text = readtextdata(fid,length-headerlength);
            %disp('NME0'); 
        case 'TAG0' % Annotation datagram
            text = readtextdata(fid,length-headerlength);
            %disp('TAG0');
        case 'RAW0' % Sample datagram
            sampledata = readsampledata(fid);
            %disp('RAW0');
 
            % WRITE YOUR OWN CODE HERE TO PROCESS AND/OR DISPLAY SAMPLE DATA
            % e.g.
            if sampledata.count>0
                figure(1)
                plot(sampledata.power)
                title('Power data')
            end
            pause

            pingno = pingno +1;
            
            str = sprintf('Read ping no. %i',pingno);
            home
            disp(str);
        otherwise
            error(strcat('Unknown datagram ''',dgheader.datagramtype,''' in file'));
        end
        length = fread(fid,1,'int32');

    end
    fclose(fid);
end

disp('Finished reading file');
    
    
